@@ -40,16 +40,20 @@ buildModelDb <- function() {
     )
   savefile <- file.path(packageDirectory, "data/modeldb.rda")
   message("Saving the modeldb to ", savefile)
-  save(modeldb, file=savefile, compress="bzip2", version=2, ascii=FALSE)
+  save(modeldb, file = savefile, compress = "bzip2", version = 2, ascii = FALSE)
   message("Done saving the modeldb to ", savefile)
 
   colDesc <-
     list(
-      name="Model name that can be used to extract the model from the model library",
-      description="Model description in free from text; in model itself",
-      parameters="A comma separated string listing either the parameter in the model defined by population/individual effects or a population effect parameter",
-      DV="The definition of the dependent variable(s)",
-      filename="Filename of the model.  By default these are installed in the model library and read on demand"
+      name = "Model name that can be used to extract the model from the model library",
+      description = "Model description in free from text; in model itself",
+      parameters  = "A comma separated string listing either the parameter in the model defined by population/individual effects or a population effect parameter",
+      DV          = "The definition of the dependent variable(s)",
+      linCmt      = "Logical flag indicating if solved models are used (TRUE) or not (FALSE)",
+      algebraic   = "Logical flag indicating if the model is purely algebraic: TRUE no linCmt() and no ODEs; FALSE otherwise",
+      dosing      = "A comma separated string of identified dosing compartments",
+      depends     = "A comma separated string of objects the model depends on",
+      filename    = "Filename of the model.  By default these are installed in the model library and read on demand"
     )
   # The names must exactly match
   stopifnot(all(names(modeldb) %in% names(colDesc)))
@@ -63,7 +67,7 @@ buildModelDb <- function() {
         collapse = ""
       )
     )
-  paste(formatText, describeText, sep="\n")
+  paste(formatText, describeText, sep = "\n")
 }
 
 #' Add a directory to the modeldb
@@ -72,7 +76,7 @@ buildModelDb <- function() {
 #' @param modeldb The starting modeldb data.frame
 #' @return The updated modeldb data.frame
 #' @export
-addDirToModelDb <- function(dir, modeldb=data.frame()) {
+addDirToModelDb <- function(dir, modeldb = data.frame()) {
   filesToLoad <-
     list.files(
       path = dir,
@@ -89,6 +93,7 @@ addDirToModelDb <- function(dir, modeldb=data.frame()) {
 
 #' @describeIn addDirToModelDb Add a file to the modeldb
 #' @param file The file name (without the directory name)
+#' @return the model database
 #' @export
 addFileToModelDb <- function(dir, file, modeldb) {
   fileName <- file.path(dir, file)
@@ -101,7 +106,8 @@ addFileToModelDb <- function(dir, file, modeldb) {
   packageStartupMessage("Loading ", modelName, " from ", fileName)
   if (modelName != tools::file_path_sans_ext(basename(file))) {
     stop("Loading model failed due to filename/modelName mismatch: ", fileName,
-         call.=FALSE) # nocov
+      call. = FALSE
+    ) # nocov
   }
 
   # Parse the model to get the fixed effects and DV parameters
@@ -113,6 +119,35 @@ addFileToModelDb <- function(dir, file, modeldb) {
     description <- NA_character_
   }
 
+  # Finding dosing
+  dosing <- NULL
+  dosing_meta <- mod$meta$dosing
+  if(!is.null(dosing_meta)){
+    dosing <- paste(dosing_meta, collapse=",")
+  }else {
+    if("depot" %in% mod$props$cmt) {
+      dosing <- c(dosing, "depot")
+    }
+    if("central" %in% mod$props$cmt) {
+      dosing <- c(dosing, "central")
+    }
+    if(!is.null(dosing)) {
+      dosing <- paste(dosing, collapse=",")
+    } else {
+      dosing <- NA_character_
+    }
+  }
+
+  # Finding depends
+  depends <- NULL
+  depends_meta <- mod$meta$depends
+  if(!is.null(depends_meta)){
+    depends = paste(depends_meta, collapse=",")
+  }
+  if(is.null(depends)){
+    depends = NA_character_
+  }
+
   # Extract the parameter names
   modParam <- mod$iniDf
   # Fixed effects
@@ -122,7 +157,7 @@ addFileToModelDb <- function(dir, file, modeldb) {
   # applicable
   .ref <- .getVarLhs(mod)
   for (nm in names(.ref)) {
-   modParamFixed[modParamFixed %in% nm] <- .ref[nm]
+    modParamFixed[modParamFixed %in% nm] <- .ref[nm]
   }
 
   # Error model
@@ -130,14 +165,29 @@ addFileToModelDb <- function(dir, file, modeldb) {
   if ("rxLinCmt" %in% paramErr) {
     paramErr[paramErr %in% "rxLinCmt"] <- "linCmt()"
   }
+  if (is.null(paramErr)) {
+    paramErr <- ""
+  }
+
+
+  if(!mod$props$linCmt && (length(mod$props$cmt)  == 0)){
+    algebraic = TRUE
+  } else {
+    algebraic = FALSE
+  }
+
 
   ret <-
     data.frame(
-      name=modelName,
-      description=description,
-      parameters=paste(modParamFixed, collapse = ","),
-      DV=paramErr,
-      filename = fileName
+      name        = modelName,
+      description = description,
+      parameters  = paste(modParamFixed, collapse = ","),
+      DV          = paste(paramErr, collapse = ","),
+      linCmt      = mod$props$linCmt,
+      algebraic   = algebraic,
+      dosing      = dosing,
+      depends     = depends,
+      filename    = fileName
     )
   modeldb <- rbind(modeldb, ret)
   if (any(duplicated(modeldb$name))) {
